@@ -106,8 +106,9 @@ class SqlAlchemyProxy:
     KW_URL = 'url'
     KW_DATABASE = 'database'
 
-    KW_REPOSITORY_DATABASE = 'database'
     KW_REPOSITORY_DIALECT = 'dialect'
+    KW_REPOSITORY_DRIVER = 'driver'
+    KW_REPOSITORY_DATABASE = 'database'
     KW_REPOSITORY_USERNAME = 'username'
     KW_REPOSITORY_PASSWORD = 'password'
     KW_REPOSITORY_HOST = 'host'
@@ -117,7 +118,7 @@ class SqlAlchemyProxy:
     KW_REPOSITORY_SETTINGS = 'settings'
 
     ENV_DATABASE_NAME = 'DATABASE_NAME'
-    KW_REPOSITORY_DRIVER = 'DATABASE_DRIVER'
+    ENV_REPOSITORY_DRIVER = 'DATABASE_DRIVER'
     ENV_DATABASE_DIALECT = 'DATABASE_DIALECT'
     ENV_DATABASE_USERNAME = 'DATABASE_USERNAME'
     ENV_DATABASE_PASSWORD = 'DATABASE_PASSWORD'
